@@ -14,26 +14,27 @@ import (
 )
 
 type Struct struct {
-	String      string
-	Int         int
-	Bool        bool
-	Strings     []string
-	Time        time.Time
-	Struct      *Struct
-	Nil         *Struct
-	Structs     []*Struct
-	Map         map[string]string
-	Stringer    Stringer
-	StringerPtr *Stringer
-	Size        *scw.Size
-	Bytes       []byte
+	String        string
+	Int           int
+	Bool          bool
+	Strings       []string
+	Time          time.Time
+	Struct        *Struct
+	Nil           *Struct
+	Structs       []*Struct
+	Map           map[string]string
+	Stringer      Stringer
+	StringerPtr   *Stringer
+	Size          *scw.Size
+	Bytes         []byte
+	MapStringList map[string][]string
 }
 
 type StructAny struct {
-	String    interface{}
-	StringPtr interface{}
-	Map       map[string]interface{}
-	MapPtr    map[string]interface{}
+	String    any
+	StringPtr any
+	Map       map[string]any
+	MapPtr    map[string]any
 }
 
 type Address struct {
@@ -70,7 +71,7 @@ func (s Stringer) String() string {
 
 func TestMarshal(t *testing.T) {
 	type testCase struct {
-		data   interface{}
+		data   any
 		opt    *human.MarshalOpt
 		result string
 	}
@@ -112,6 +113,77 @@ func TestMarshal(t *testing.T) {
 				"key1": "v1",
 				"key2": "v2",
 			},
+			MapStringList: map[string][]string{
+				"key1": {"v1", "v2"},
+				"key2": {"v3", "v4"},
+			},
+			Stringer:    Stringer{},
+			StringerPtr: &Stringer{},
+			Size:        scw.SizePtr(13200),
+			Bytes:       []byte{0, 1},
+		},
+		result: `
+			String                This is a string
+			Int                   42
+			Bool                  true
+			Strings.0             s1
+			Strings.1             s2
+			Time                  ` + humanDate + `
+			Struct.String         -
+			Struct.Int            0
+			Struct.Bool           false
+			Struct.Time           a long while ago
+			Struct.Stringer       a stringer
+			Structs.0.String      Nested string
+			Structs.0.Int         0
+			Structs.0.Bool        false
+			Structs.0.Time        a long while ago
+			Structs.0.Stringer    a stringer
+			Map.key1              v1
+			Map.key2              v2
+			Stringer              a stringer
+			StringerPtr           a stringer
+			Size                  13 kB
+			Bytes                 AAE=
+			MapStringList.key1.0  v1
+			MapStringList.key1.1  v2
+			MapStringList.key2.0  v3
+			MapStringList.key2.1  v4
+		`,
+	}))
+
+	t.Run("structWithMapsInSection", run(&testCase{
+		opt: &human.MarshalOpt{
+			Sections: []*human.MarshalSection{
+				{
+					FieldName: "MapStringList",
+				},
+				{
+					FieldName: "Map",
+				},
+			},
+		},
+		data: &Struct{
+			String:  "This is a string",
+			Int:     42,
+			Bool:    true,
+			Strings: []string{"s1", "s2"},
+			Time:    date,
+			Struct:  &Struct{},
+			Nil:     nil,
+			Structs: []*Struct{
+				{
+					String: "Nested string",
+				},
+			},
+			Map: map[string]string{
+				"key1": "v1",
+				"key2": "v2",
+			},
+			MapStringList: map[string][]string{
+				"key1": {"v1", "v2"},
+				"key2": {"v3", "v4"},
+			},
 			Stringer:    Stringer{},
 			StringerPtr: &Stringer{},
 			Size:        scw.SizePtr(13200),
@@ -123,7 +195,7 @@ func TestMarshal(t *testing.T) {
 			Bool                true
 			Strings.0           s1
 			Strings.1           s2
-			Time                ` + humanDate + `
+			Time                35 years ago
 			Struct.String       -
 			Struct.Int          0
 			Struct.Bool         false
@@ -134,12 +206,18 @@ func TestMarshal(t *testing.T) {
 			Structs.0.Bool      false
 			Structs.0.Time      a long while ago
 			Structs.0.Stringer  a stringer
-			Map.key1            v1
-			Map.key2            v2
 			Stringer            a stringer
 			StringerPtr         a stringer
 			Size                13 kB
 			Bytes               AAE=
+
+			Map String List:
+			key1  v1 v2
+			key2  v3 v4
+
+			Map:
+			key1  v1
+			key2  v2
 		`,
 	}))
 
@@ -292,10 +370,10 @@ func TestMarshal(t *testing.T) {
 		data: &StructAny{
 			String:    testAnyString,
 			StringPtr: &testAnyString,
-			Map: map[string]interface{}{
+			Map: map[string]any{
 				"String": testAnyString,
 			},
-			MapPtr: map[string]interface{}{
+			MapPtr: map[string]any{
 				"String": &testAnyString,
 			},
 		},
@@ -338,7 +416,7 @@ func Test_getStructFieldsIndex(t *testing.T) {
 				},
 				),
 			},
-			want: [][]int{{0}, {1}, {2}, {3}, {4}, {5}, {6}, {7}, {8}, {9}, {10}, {11}, {12}},
+			want: [][]int{{0}, {1}, {2}, {3}, {4}, {5}, {6}, {7}, {8}, {9}, {10}, {11}, {12}, {13}},
 		},
 	}
 	for _, tt := range tests {
