@@ -45,15 +45,26 @@ var (
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
 
+	cmds.MustFind("block").Groups = []string{"storage"}
+
 	cmds.Add(volumeWaitCommand())
 	cmds.Add(snapshotWaitCommand())
 
 	cmds.MustFind("block", "snapshot", "create").Override(blockSnapshotCreateBuilder)
 	cmds.MustFind("block", "volume", "create").Override(blockVolumeCreateBuilder)
 
-	human.RegisterMarshalerFunc(block.VolumeStatus(""), human.EnumMarshalFunc(volumeStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(block.SnapshotStatus(""), human.EnumMarshalFunc(snapshotStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(block.ReferenceStatus(""), human.EnumMarshalFunc(referenceStatusMarshalSpecs))
+	human.RegisterMarshalerFunc(
+		block.VolumeStatus(""),
+		human.EnumMarshalFunc(volumeStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		block.SnapshotStatus(""),
+		human.EnumMarshalFunc(snapshotStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		block.ReferenceStatus(""),
+		human.EnumMarshalFunc(referenceStatusMarshalSpecs),
+	)
 
 	return cmds
 }
