@@ -7,7 +7,7 @@ package config
 import (
 	"fmt"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
+	"github.com/scaleway/scaleway-cli/v2/core"
 )
 
 func invalidProfileKeyError(fieldName string) *core.CliError {
