@@ -2,7 +2,7 @@ package container
 
 import (
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/human"
+	"github.com/scaleway/scaleway-cli/v2/core/human"
 	container "github.com/scaleway/scaleway-sdk-go/api/container/v1beta1"
 )
 
