@@ -9,7 +9,12 @@ import (
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
 
-	human.RegisterMarshalerFunc(inference.DeploymentStatus(""), human.EnumMarshalFunc(deployementStateMarshalSpecs))
+	cmds.MustFind("inference").Groups = []string{"ai"}
+
+	human.RegisterMarshalerFunc(
+		inference.DeploymentStatus(""),
+		human.EnumMarshalFunc(deployementStateMarshalSpecs),
+	)
 
 	human.RegisterMarshalerFunc(inference.Deployment{}, DeploymentMarshalerFunc)
 	human.RegisterMarshalerFunc([]*inference.Model{}, ListModelMarshalerFunc)
