@@ -47,7 +47,7 @@ var (
 )
 
 // serverLocationMarshalerFunc marshals a instance.ServerLocation.
-func serverLocationMarshalerFunc(i interface{}, _ *human.MarshalOpt) (string, error) {
+func serverLocationMarshalerFunc(i any, _ *human.MarshalOpt) (string, error) {
 	location := i.(instance.ServerLocation)
 	zone, err := scw.ParseZone(location.ZoneID)
 	if err != nil {
@@ -58,7 +58,7 @@ func serverLocationMarshalerFunc(i interface{}, _ *human.MarshalOpt) (string, er
 }
 
 // serversMarshalerFunc marshals a Server.
-func serversMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func serversMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	// humanServerInList is the custom Server type used for list view.
 	type humanServerInList struct {
 		ID                string
@@ -152,8 +152,13 @@ func orderVolumes(v map[string]*customVolume) []*customVolume {
 	return orderedVolumes
 }
 
+type ServerWithWarningsResponse struct {
+	*instance.Server
+	Warnings []string
+}
+
 // serversMarshalerFunc marshals a BootscriptID.
-func bootscriptMarshalerFunc(i interface{}, _ *human.MarshalOpt) (string, error) {
+func bootscriptMarshalerFunc(i any, _ *human.MarshalOpt) (string, error) {
 	bootscript := i.(instance.Bootscript)
 
 	return bootscript.Title, nil
@@ -176,7 +181,7 @@ func serverListBuilder(c *core.Command) *core.Command {
 	c.ArgsType = reflect.TypeOf(customListServersRequest{})
 
 	c.AddInterceptors(
-		func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (i interface{}, err error) {
+		func(ctx context.Context, argsI any, runner core.CommandRunner) (i any, err error) {
 			args := argsI.(*customListServersRequest)
 
 			if args.ListServersRequest == nil {
@@ -235,7 +240,7 @@ func serverUpdateBuilder(c *core.Command) *core.Command {
 		CanLoadFile: true,
 	})
 
-	c.Run = func(ctx context.Context, argsI interface{}) (i interface{}, e error) {
+	c.Run = func(ctx context.Context, argsI any) (i any, e error) {
 		customRequest := argsI.(*instanceUpdateServerRequestCustom)
 
 		updateServerRequest := customRequest.UpdateServerRequest
@@ -349,7 +354,27 @@ func serverUpdateBuilder(c *core.Command) *core.Command {
 			return nil, err
 		}
 
-		return updateServerResponse, nil
+		// Display warning if server-type is deprecated
+		warnings := []string(nil)
+		server := updateServerResponse.Server
+		if server.EndOfService {
+			warnings = warningServerTypeDeprecated(ctx, client, server)
+		}
+
+		return &ServerWithWarningsResponse{
+			server,
+			warnings,
+		}, nil
+	}
+
+	c.View = &core.View{
+		Sections: []*core.ViewSection{
+			{
+				FieldName:   "Warnings",
+				Title:       "Warnings",
+				HideIfEmpty: true,
+			},
+		},
 	}
 
 	return c
@@ -386,12 +411,13 @@ func serverGetBuilder(c *core.Command) *core.Command {
 		return suggestion
 	}
 
-	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+	c.Interceptor = func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 		rawResp, err := runner(ctx, argsI)
 		if err != nil {
 			return rawResp, err
 		}
 		getServerResp := rawResp.(*instance.GetServerResponse)
+		server := getServerResp.Server
 
 		client := core.ExtractClient(ctx)
 		vpcAPI := vpc.NewAPI(client)
@@ -405,8 +431,8 @@ func serverGetBuilder(c *core.Command) *core.Command {
 
 		nics := []customNICs{}
 
-		for _, nic := range getServerResp.Server.PrivateNics {
-			region, err := getServerResp.Server.Zone.Region()
+		for _, nic := range server.PrivateNics {
+			region, err := server.Zone.Region()
 			if err != nil {
 				return nil, err
 			}
@@ -428,7 +454,7 @@ func serverGetBuilder(c *core.Command) *core.Command {
 		volumes := map[string]*customVolume{}
 		blockAPI := block.NewAPI(client)
 
-		for _, volume := range getServerResp.Server.Volumes {
+		for _, volume := range server.Volumes {
 			customVol := &customVolume{
 				ID:   volume.ID,
 				Zone: volume.Zone.String(),
@@ -473,14 +499,22 @@ func serverGetBuilder(c *core.Command) *core.Command {
 			volumes[volume.ID] = customVol
 		}
 
+		// Display warning if server-type is deprecated
+		warnings := []string(nil)
+		if server.EndOfService {
+			warnings = warningServerTypeDeprecated(ctx, client, server)
+		}
+
 		return &struct {
 			*instance.Server
 			Volumes     []*customVolume
 			PrivateNics []customNICs `json:"private_nics"`
+			Warnings    []string     `json:"warnings"`
 		}{
-			getServerResp.Server,
+			server,
 			orderVolumes(volumes),
 			nics,
+			warnings,
 		}, nil
 	}
 
@@ -510,6 +544,15 @@ func serverGetBuilder(c *core.Command) *core.Command {
 				FieldName: "PrivateNics",
 				Title:     "Private NICs",
 			},
+			{
+				FieldName:   "Warnings",
+				Title:       "Warnings",
+				HideIfEmpty: true,
+			},
+			{
+				FieldName: "Filesystems",
+				Title:     "Server Filesystems",
+			},
 		},
 	}
 
@@ -540,7 +583,7 @@ func serverAttachVolumeCommand() *core.Command {
 			},
 			core.ZoneArgSpec((*instance.API)(nil).Zones()...),
 		},
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			request := argsI.(*instance.AttachVolumeRequest)
 
 			client := core.ExtractClient(ctx)
@@ -572,7 +615,7 @@ func serverDetachVolumeCommand() *core.Command {
 			},
 			core.ZoneArgSpec((*instance.API)(nil).Zones()...),
 		},
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			request := argsI.(*instance.DetachVolumeRequest)
 
 			client := core.ExtractClient(ctx)
@@ -619,7 +662,7 @@ func serverAttachIPCommand() *core.Command {
 			},
 			core.ZoneArgSpec((*instance.API)(nil).Zones()...),
 		},
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			api := instance.NewAPI(core.ExtractClient(ctx))
 			args := argsI.(*customIPAttachRequest)
 
@@ -694,7 +737,7 @@ func serverDetachIPCommand() *core.Command {
 			},
 			core.ZoneArgSpec((*instance.API)(nil).Zones()...),
 		},
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			args := argsI.(*customIPDetachRequest)
 
 			client := core.ExtractClient(ctx)
@@ -752,7 +795,7 @@ func serverWaitCommand() *core.Command {
 		Verb:      "wait",
 		Groups:    []string{"workflow"},
 		ArgsType:  reflect.TypeOf(serverWaitRequest{}),
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			args := argsI.(*serverWaitRequest)
 
 			return instance.NewAPI(core.ExtractClient(ctx)).
