@@ -2,7 +2,7 @@
 
 package instance
 
-import "github.com/scaleway/scaleway-cli/v2/internal/core"
+import "github.com/scaleway/scaleway-cli/v2/core"
 
 func serverConsoleCommand() *core.Command {
 	return nil
