@@ -9,7 +9,6 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/sshconfig"
-	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -30,7 +29,7 @@ func Test_SSHConfigInstall(t *testing.T) {
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				server := ctx.Meta["Server"].(*instance.ServerWithWarningsResponse).Server
 
 				configPath := sshconfig.ConfigFilePath(ctx.Meta["HOME"].(string))
 				content, err := os.ReadFile(configPath)
@@ -72,7 +71,7 @@ func Test_SSHConfigInstall(t *testing.T) {
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				server := ctx.Meta["Server"].(*instanceSDK.Server)
+				server := ctx.Meta["Server"].(*instance.ServerWithWarningsResponse).Server
 
 				defaultConfigPath := sshconfig.DefaultConfigFilePath(ctx.Meta["HOME"].(string))
 				content, err := os.ReadFile(defaultConfigPath)
