@@ -9,8 +9,16 @@ import (
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
 
-	human.RegisterMarshalerFunc(interlink.BgpStatus(""), human.EnumMarshalFunc(bgpStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(interlink.LinkStatus(""), human.EnumMarshalFunc(linkStatusMarshalSpecs))
+	cmds.MustFind("interlink").Groups = []string{"network"}
+
+	human.RegisterMarshalerFunc(
+		interlink.BgpStatus(""),
+		human.EnumMarshalFunc(bgpStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		interlink.LinkStatus(""),
+		human.EnumMarshalFunc(linkStatusMarshalSpecs),
+	)
 
 	return cmds
 }
