@@ -43,7 +43,7 @@ const (
 	clusterActionDelete
 )
 
-func clusterMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func clusterMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	type humanCluster k8s.Cluster
 	cluster := humanCluster(i.(k8s.Cluster))
 
@@ -71,7 +71,7 @@ func clusterMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error)
 	return str, nil
 }
 
-func clusterAvailableTypesListMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func clusterAvailableTypesListMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	type humanResponse k8s.ListClusterAvailableTypesResponse
 	types := humanResponse(i.(k8s.ListClusterAvailableTypesResponse))
 
@@ -93,7 +93,7 @@ func clusterAvailableTypesListMarshalerFunc(i interface{}, opt *human.MarshalOpt
 
 func clusterAvailableVersionsListBuilder(c *core.Command) *core.Command {
 	c.AddInterceptors(
-		func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+		func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 			originalRes, err := runner(ctx, argsI)
 			if err != nil {
 				return nil, err
@@ -119,7 +119,7 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("version").AutoCompleteFunc = autocompleteK8SVersion
 	c.ArgSpecs.GetByName("type").AutoCompleteFunc = autocompleteClusterType
 
-	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+	c.Interceptor = func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 		args := argsI.(*k8s.CreateClusterRequest)
 
 		// Handle default latest version for k8s cluster
@@ -134,7 +134,7 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 		return runner(ctx, args)
 	}
 
-	c.Run = func(ctx context.Context, args interface{}) (i interface{}, e error) {
+	c.Run = func(ctx context.Context, args any) (i any, e error) {
 		request := args.(*k8s.CreateClusterRequest)
 
 		client := core.ExtractClient(ctx)
@@ -245,7 +245,7 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 }
 
 func clusterGetBuilder(c *core.Command) *core.Command {
-	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+	c.Interceptor = func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 		res, err := runner(ctx, argsI)
 		if err != nil {
 			return nil, err
@@ -345,7 +345,7 @@ func clusterUpdateBuilder(c *core.Command) *core.Command {
 }
 
 func waitForClusterFunc(action int) core.WaitFunc {
-	return func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	return func(ctx context.Context, _, respI any) (any, error) {
 		var clusterResponse *k8s.Cluster
 		if action == clusterActionCreate {
 			clusterResponse = respI.(struct {
@@ -400,7 +400,7 @@ func k8sClusterWaitCommand() *core.Command {
 		Verb:      "wait",
 		Groups:    []string{"workflow"},
 		ArgsType:  reflect.TypeOf(customClusterWaitArgs{}),
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			args := argsI.(*customClusterWaitArgs)
 
 			api := k8s.NewAPI(core.ExtractClient(ctx))
