@@ -50,7 +50,7 @@ If the current context points to this cluster, it will be set to an empty contex
 
 // k8sKubeconfigUninstallRun use the specified cluster ID to remove it from the wanted kubeconfig file
 // it removes all the users, contexts and clusters that contains this ID from the file
-func k8sKubeconfigUninstallRun(ctx context.Context, argsI interface{}) (i interface{}, e error) {
+func k8sKubeconfigUninstallRun(ctx context.Context, argsI any) (i any, e error) {
 	request := argsI.(*k8sKubeconfigUninstallRequest)
 
 	kubeconfigPath, err := getKubeconfigPath(ctx)
