@@ -14,6 +14,9 @@ import (
 // - Apply handwritten overrides (of Command.Run)
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
+
+	cmds.MustFind("registry").Groups = []string{"container", "storage"}
+
 	cmds.Merge(core.NewCommands(
 		registryLoginCommand(),
 		registryLogoutCommand(),
@@ -30,9 +33,18 @@ func GetCommands() *core.Commands {
 	cmds.MustFind("registry", "image", "get").Override(imageGetBuilder)
 	cmds.MustFind("registry", "image", "list").Override(imageListBuilder)
 
-	human.RegisterMarshalerFunc(registry.NamespaceStatus(""), human.EnumMarshalFunc(namespaceStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(registry.ImageStatus(""), human.EnumMarshalFunc(imageStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(registry.TagStatus(""), human.EnumMarshalFunc(tagStatusMarshalSpecs))
+	human.RegisterMarshalerFunc(
+		registry.NamespaceStatus(""),
+		human.EnumMarshalFunc(namespaceStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		registry.ImageStatus(""),
+		human.EnumMarshalFunc(imageStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		registry.TagStatus(""),
+		human.EnumMarshalFunc(tagStatusMarshalSpecs),
+	)
 
 	return cmds
 }
