@@ -45,7 +45,7 @@ It avoid running docker login commands.
 				Name:    "path",
 				Short:   "Directory in which the Docker helper will be installed. This directory should be in your $PATH",
 				Default: core.DefaultValueSetter("/usr/local/bin"),
-				ValidateFunc: func(_ *core.ArgSpec, value interface{}) error {
+				ValidateFunc: func(_ *core.ArgSpec, value any) error {
 					stat, err := os.Stat(value.(string))
 					if err != nil || !stat.IsDir() {
 						return fmt.Errorf("%s is not a directory", value)
@@ -59,7 +59,7 @@ It avoid running docker login commands.
 	}
 }
 
-func registrySetupDockerHelperRun(ctx context.Context, argsI interface{}) (i interface{}, e error) {
+func registrySetupDockerHelperRun(ctx context.Context, argsI any) (i any, e error) {
 	// TODO add windows support
 	if runtime.GOOS == "windows" {
 		return nil, core.WindowIsNotSupportedError()
@@ -174,7 +174,7 @@ func registryDockerHelperGetCommand() *core.Command {
 	}
 }
 
-func registryDockerHelperGetRun(ctx context.Context, _ interface{}) (i interface{}, e error) {
+func registryDockerHelperGetRun(ctx context.Context, _ any) (i any, e error) {
 	var serverURL string
 	serverURL, err := bufio.NewReader(core.ExtractStdin(ctx)).ReadString('\n')
 	if err != nil && err != io.EOF {
@@ -221,7 +221,7 @@ func registryDockerHelperStoreCommand() *core.Command {
 		Resource:  "docker-helper",
 		Verb:      "store",
 		ArgsType:  reflect.TypeOf(emptyRequest{}),
-		Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+		Run: func(_ context.Context, _ any) (i any, e error) {
 			return nil, nil
 		},
 	}
@@ -237,7 +237,7 @@ func registryDockerHelperEraseCommand() *core.Command {
 		ArgSpecs: []*core.ArgSpec{
 			{},
 		},
-		Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+		Run: func(_ context.Context, _ any) (i any, e error) {
 			return nil, nil
 		},
 	}
@@ -250,7 +250,7 @@ func registryDockerHelperListCommand() *core.Command {
 		Resource:  "docker-helper",
 		Verb:      "list",
 		ArgsType:  reflect.TypeOf(emptyRequest{}),
-		Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+		Run: func(_ context.Context, _ any) (i any, e error) {
 			registryEndpoints := make(map[string]string)
 			for _, region := range scw.AllRegions {
 				registryEndpoints[getRegistryEndpoint(region)] = "scaleway"
