@@ -5,18 +5,23 @@ import (
 
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/core/human"
+	applesilicon "github.com/scaleway/scaleway-sdk-go/api/applesilicon/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
+	inference "github.com/scaleway/scaleway-sdk-go/api/inference/v1beta1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
+	"github.com/scaleway/scaleway-sdk-go/api/ipam/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/k8s/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/lb/v1"
+	mongodb "github.com/scaleway/scaleway-sdk-go/api/mongodb/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/rdb/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/redis/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/vpc/v2"
-	"github.com/scaleway/scaleway-sdk-go/api/vpcgw/v1"
+	"github.com/scaleway/scaleway-sdk-go/api/vpcgw/v2"
 	"github.com/scaleway/scaleway-sdk-go/scw"
+	"golang.org/x/sync/errgroup"
 )
 
-func privateNetworkMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func privateNetworkMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	type tmp vpc.PrivateNetwork
 	pn := tmp(i.(vpc.PrivateNetwork))
 
@@ -38,7 +43,7 @@ func privateNetworkMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string,
 }
 
 func privateNetworkGetBuilder(c *core.Command) *core.Command {
-	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+	c.Interceptor = func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 		getPNResp, err := runner(ctx, argsI)
 		if err != nil {
 			return getPNResp, err
@@ -47,71 +52,118 @@ func privateNetworkGetBuilder(c *core.Command) *core.Command {
 
 		client := core.ExtractClient(ctx)
 
-		// Instance
-		listInstanceServers, err := listCustomInstanceServers(client, pn)
-		if err != nil {
-			return nil, err
-		}
+		var (
+			instanceServers      []customInstanceServer
+			baremetalServers     []customBaremetalServer
+			k8sClusters          []customK8sCluster
+			lbs                  []customLB
+			rdbs                 []customRdb
+			redisClusters        []customRedis
+			gateways             []customGateway
+			appleSiliconServers  []customAppleSiliconServer
+			mongoDBs             []customMongoDB
+			ipamIPs              []customIPAMIP
+			inferenceDeployments []customInferenceDeployment
+		)
 
-		// Baremetal
-		listBaremetalServers, err := listCustomBaremetalServers(client, pn)
-		if err != nil {
-			return nil, err
-		}
+		g, groupCtx := errgroup.WithContext(ctx)
 
-		// K8s
-		listK8sClusters, err := listCustomK8sClusters(client, pn)
-		if err != nil {
-			return nil, err
-		}
+		g.Go(func() (err error) {
+			instanceServers, err = listCustomInstanceServers(groupCtx, client, pn)
 
-		// LB
-		listLBs, err := listCustomLBs(client, pn)
-		if err != nil {
-			return nil, err
-		}
+			return
+		})
+		g.Go(func() (err error) {
+			baremetalServers, err = listCustomBaremetalServers(groupCtx, client, pn)
 
-		// Rdb
-		listRdbInstances, err := listCustomRdbs(client, pn)
-		if err != nil {
-			return nil, err
-		}
+			return
+		})
+		g.Go(func() (err error) {
+			k8sClusters, err = listCustomK8sClusters(groupCtx, client, pn)
 
-		// Redis
-		listRedisClusters, err := listCustomRedisClusters(client, pn)
-		if err != nil {
-			return nil, err
-		}
+			return
+		})
+		g.Go(func() (err error) {
+			lbs, err = listCustomLBs(groupCtx, client, pn)
 
-		// Gateway
-		listGateways, err := listCustomGateways(client, pn)
-		if err != nil {
+			return
+		})
+		g.Go(func() (err error) {
+			rdbs, err = listCustomRdbs(groupCtx, client, pn)
+
+			return
+		})
+		g.Go(func() (err error) {
+			redisClusters, err = listCustomRedisClusters(groupCtx, client, pn)
+
+			return
+		})
+		g.Go(func() (err error) {
+			gateways, err = listCustomGateways(groupCtx, client, pn)
+
+			return
+		})
+		g.Go(func() (err error) {
+			appleSiliconServers, err = listCustomAppleSiliconServers(groupCtx, client, pn)
+
+			return
+		})
+		g.Go(func() (err error) {
+			mongoDBs, err = listCustomMongoDBs(groupCtx, client, pn)
+
+			return
+		})
+		g.Go(func() (err error) {
+			ipamIPs, err = listCustomIPAMIPs(groupCtx, client, pn)
+
+			return
+		})
+		g.Go(func() (err error) {
+			inferenceDeployments, err = listCustomInferenceDeployments(groupCtx, client, pn)
+
+			return
+		})
+
+		if err = g.Wait(); err != nil {
 			return nil, err
 		}
 
 		return &struct {
 			*vpc.PrivateNetwork
-			InstanceServers  []customInstanceServer  `json:"instance_servers,omitempty"`
-			BaremetalServers []customBaremetalServer `json:"baremetal_servers,omitempty"`
-			K8sClusters      []customK8sCluster      `json:"K8s_clusters,omitempty"`
-			LBs              []customLB              `json:"lbs,omitempty"`
-			RdbInstances     []customRdb             `json:"rdb_instances,omitempty"`
-			RedisClusters    []customRedis           `json:"redis_clusters,omitempty"`
-			Gateways         []customGateway         `json:"gateways,omitempty"`
+			InstanceServers      []customInstanceServer      `json:"instance_servers,omitempty"`
+			BaremetalServers     []customBaremetalServer     `json:"baremetal_servers,omitempty"`
+			K8sClusters          []customK8sCluster          `json:"K8s_clusters,omitempty"`
+			LBs                  []customLB                  `json:"lbs,omitempty"`
+			RdbInstances         []customRdb                 `json:"rdb_instances,omitempty"`
+			RedisClusters        []customRedis               `json:"redis_clusters,omitempty"`
+			Gateways             []customGateway             `json:"gateways,omitempty"`
+			AppleSiliconServers  []customAppleSiliconServer  `json:"apple_silicon_servers,omitempty"`
+			MongoDBInstances     []customMongoDB             `json:"mongodb_instances,omitempty"`
+			IPAMIPs              []customIPAMIP              `json:"ipam_ips,omitempty"`
+			InferenceDeployments []customInferenceDeployment `json:"inference_deployments,omitempty"`
 		}{
 			pn,
-			listInstanceServers,
-			listBaremetalServers,
-			listK8sClusters,
-			listLBs,
-			listRdbInstances,
-			listRedisClusters,
-			listGateways,
+			instanceServers,
+			baremetalServers,
+			k8sClusters,
+			lbs,
+			rdbs,
+			redisClusters,
+			gateways,
+			appleSiliconServers,
+			mongoDBs,
+			ipamIPs,
+			inferenceDeployments,
 		}, nil
 	}
 
 	c.View = &core.View{
 		Sections: []*core.ViewSection{
+			{
+				FieldName:   "Subnets",
+				Title:       "Subnets",
+				HideIfEmpty: true,
+			},
 			{
 				FieldName:   "InstanceServers",
 				Title:       "Instance Servers",
@@ -148,8 +200,23 @@ func privateNetworkGetBuilder(c *core.Command) *core.Command {
 				HideIfEmpty: true,
 			},
 			{
-				FieldName:   "Subnets",
-				Title:       "Subnets",
+				FieldName:   "AppleSiliconServers",
+				Title:       "AppleSilicon Servers",
+				HideIfEmpty: true,
+			},
+			{
+				FieldName:   "MongoDBInstances",
+				Title:       "MongoDB Instances",
+				HideIfEmpty: true,
+			},
+			{
+				FieldName:   "IPAMIPs",
+				Title:       "IPAM IPs",
+				HideIfEmpty: true,
+			},
+			{
+				FieldName:   "InferenceDeployments",
+				Title:       "Inference Deployments",
 				HideIfEmpty: true,
 			},
 		},
@@ -194,6 +261,13 @@ type customRedis struct {
 	State      redis.ClusterStatus `json:"state"`
 	EndpointID string              `json:"endpoint_id"`
 }
+
+type customMongoDB struct {
+	ID         string                 `json:"id"`
+	Name       string                 `json:"name"`
+	State      mongodb.InstanceStatus `json:"state"`
+	EndpointID string                 `json:"endpoint_id"`
+}
 type customGateway struct {
 	ID               string              `json:"id"`
 	Name             string              `json:"name"`
@@ -201,7 +275,28 @@ type customGateway struct {
 	GatewayNetworkID string              `json:"gateway_network_id"`
 }
 
+type customAppleSiliconServer struct {
+	ID        string                    `json:"id"`
+	Name      string                    `json:"name"`
+	State     applesilicon.ServerStatus `json:"state"`
+	Vlan      *uint32                   `json:"vlan"`
+	MappingId string                    `json:"mapping_id"`
+}
+
+type customIPAMIP struct {
+	ID      string `json:"id"`
+	Address string `json:"address"`
+}
+
+type customInferenceDeployment struct {
+	ID         string                     `json:"id"`
+	Name       string                     `json:"name"`
+	State      inference.DeploymentStatus `json:"state"`
+	EndpointID string                     `json:"endpoint_id"`
+}
+
 func listCustomInstanceServers(
+	ctx context.Context,
 	client *scw.Client,
 	pn *vpc.PrivateNetwork,
 ) ([]customInstanceServer, error) {
@@ -216,7 +311,7 @@ func listCustomInstanceServers(
 		listInstanceServers, err := instanceAPI.ListServers(&instance.ListServersRequest{
 			PrivateNetwork: &pn.ID,
 			Zone:           zone,
-		}, scw.WithAllPages())
+		}, scw.WithContext(ctx), scw.WithAllPages())
 		if err != nil {
 			return nil, err
 		}
@@ -239,6 +334,7 @@ func listCustomInstanceServers(
 }
 
 func listCustomBaremetalServers(
+	ctx context.Context,
 	client *scw.Client,
 	pn *vpc.PrivateNetwork,
 ) ([]customBaremetalServer, error) {
@@ -255,8 +351,7 @@ func listCustomBaremetalServers(
 			&baremetal.PrivateNetworkAPIListServerPrivateNetworksRequest{
 				Zone:             zone,
 				PrivateNetworkID: &pn.ID,
-			},
-			scw.WithAllPages(),
+			}, scw.WithContext(ctx), scw.WithAllPages(),
 		)
 		if err != nil {
 			return nil, err
@@ -267,7 +362,7 @@ func listCustomBaremetalServers(
 				getBaremetalServer, err := baremetalAPI.GetServer(&baremetal.GetServerRequest{
 					Zone:     zone,
 					ServerID: server.ServerID,
-				})
+				}, scw.WithContext(ctx))
 				if err != nil {
 					return nil, err
 				}
@@ -285,12 +380,16 @@ func listCustomBaremetalServers(
 	return customBaremetalServers, nil
 }
 
-func listCustomK8sClusters(client *scw.Client, pn *vpc.PrivateNetwork) ([]customK8sCluster, error) {
+func listCustomK8sClusters(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customK8sCluster, error) {
 	k8sAPI := k8s.NewAPI(client)
 
 	listK8sClusters, err := k8sAPI.ListClusters(&k8s.ListClustersRequest{
 		Region: pn.Region,
-	}, scw.WithAllPages())
+	}, scw.WithContext(ctx), scw.WithAllPages())
 	if err != nil {
 		return nil, err
 	}
@@ -308,7 +407,11 @@ func listCustomK8sClusters(client *scw.Client, pn *vpc.PrivateNetwork) ([]custom
 	return customK8sClusters, nil
 }
 
-func listCustomLBs(client *scw.Client, pn *vpc.PrivateNetwork) ([]customLB, error) {
+func listCustomLBs(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customLB, error) {
 	LBAPI := lb.NewZonedAPI(client)
 
 	regionZones := pn.Region.GetZones()
@@ -319,7 +422,7 @@ func listCustomLBs(client *scw.Client, pn *vpc.PrivateNetwork) ([]customLB, erro
 	for _, zone := range zones {
 		listLbs, err := LBAPI.ListLBs(&lb.ZonedAPIListLBsRequest{
 			Zone: zone,
-		})
+		}, scw.WithContext(ctx), scw.WithAllPages())
 		if err != nil {
 			return nil, err
 		}
@@ -335,7 +438,7 @@ func listCustomLBs(client *scw.Client, pn *vpc.PrivateNetwork) ([]customLB, erro
 			listLBpns, err := LBAPI.ListLBPrivateNetworks(&lb.ZonedAPIListLBPrivateNetworksRequest{
 				Zone: zone,
 				LBID: loadbalancer.ID,
-			}, scw.WithAllPages())
+			}, scw.WithContext(ctx), scw.WithAllPages())
 			if err != nil {
 				return nil, err
 			}
@@ -354,12 +457,16 @@ func listCustomLBs(client *scw.Client, pn *vpc.PrivateNetwork) ([]customLB, erro
 	return customLBs, nil
 }
 
-func listCustomRdbs(client *scw.Client, pn *vpc.PrivateNetwork) ([]customRdb, error) {
+func listCustomRdbs(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customRdb, error) {
 	rdbAPI := rdb.NewAPI(client)
 
 	listDBs, err := rdbAPI.ListInstances(&rdb.ListInstancesRequest{
 		Region: pn.Region,
-	}, scw.WithAllPages())
+	}, scw.WithContext(ctx), scw.WithAllPages())
 	if err != nil {
 		return nil, err
 	}
@@ -380,7 +487,11 @@ func listCustomRdbs(client *scw.Client, pn *vpc.PrivateNetwork) ([]customRdb, er
 	return customRdbs, nil
 }
 
-func listCustomRedisClusters(client *scw.Client, pn *vpc.PrivateNetwork) ([]customRedis, error) {
+func listCustomRedisClusters(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customRedis, error) {
 	redisAPI := redis.NewAPI(client)
 
 	regionZones := pn.Region.GetZones()
@@ -391,7 +502,7 @@ func listCustomRedisClusters(client *scw.Client, pn *vpc.PrivateNetwork) ([]cust
 	for _, zone := range zones {
 		listRedisClusters, err := redisAPI.ListClusters(&redis.ListClustersRequest{
 			Zone: zone,
-		}, scw.WithAllPages())
+		}, scw.WithContext(ctx), scw.WithAllPages())
 		if err != nil {
 			return nil, err
 		}
@@ -412,7 +523,11 @@ func listCustomRedisClusters(client *scw.Client, pn *vpc.PrivateNetwork) ([]cust
 	return customClusters, nil
 }
 
-func listCustomGateways(client *scw.Client, pn *vpc.PrivateNetwork) ([]customGateway, error) {
+func listCustomGateways(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customGateway, error) {
 	vpcgwAPI := vpcgw.NewAPI(client)
 
 	regionZones := pn.Region.GetZones()
@@ -421,10 +536,9 @@ func listCustomGateways(client *scw.Client, pn *vpc.PrivateNetwork) ([]customGat
 
 	var customGateways []customGateway
 	for _, zone := range zones {
-		//nolint: staticcheck
 		listGateways, err := vpcgwAPI.ListGateways(&vpcgw.ListGatewaysRequest{
 			Zone: zone,
-		}, scw.WithAllPages())
+		}, scw.WithContext(ctx), scw.WithAllPages())
 		if err != nil {
 			return nil, err
 		}
@@ -445,6 +559,146 @@ func listCustomGateways(client *scw.Client, pn *vpc.PrivateNetwork) ([]customGat
 	return customGateways, nil
 }
 
+func listCustomAppleSiliconServers(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customAppleSiliconServer, error) {
+	appleSiliconAPI := applesilicon.NewAPI(client)
+	appleSiliconPrivateNetworkAPI := applesilicon.NewPrivateNetworkAPI(client)
+
+	regionZones := pn.Region.GetZones()
+	appleSiliconZones := appleSiliconAPI.Zones()
+	zones := intersectZones(regionZones, appleSiliconZones)
+
+	var customAppleSiliconServers []customAppleSiliconServer
+
+	for _, zone := range zones {
+		listAppleSiliconServers, err := appleSiliconPrivateNetworkAPI.ListServerPrivateNetworks(
+			&applesilicon.PrivateNetworkAPIListServerPrivateNetworksRequest{
+				Zone:             zone,
+				PrivateNetworkID: &pn.ID,
+			}, scw.WithContext(ctx), scw.WithAllPages(),
+		)
+		if err != nil {
+			return nil, err
+		}
+
+		for _, server := range listAppleSiliconServers.ServerPrivateNetworks {
+			if server.PrivateNetworkID == pn.ID {
+				getAppleSiliconServer, err := appleSiliconAPI.GetServer(
+					&applesilicon.GetServerRequest{
+						Zone:     zone,
+						ServerID: server.ServerID,
+					}, scw.WithContext(ctx),
+				)
+				if err != nil {
+					return nil, err
+				}
+
+				customAppleSiliconServers = append(
+					customAppleSiliconServers,
+					customAppleSiliconServer{
+						ID:        getAppleSiliconServer.ID,
+						Name:      getAppleSiliconServer.Name,
+						State:     getAppleSiliconServer.Status,
+						Vlan:      server.Vlan,
+						MappingId: server.ID,
+					},
+				)
+			}
+		}
+	}
+
+	return customAppleSiliconServers, nil
+}
+
+func listCustomMongoDBs(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customMongoDB, error) {
+	mongoAPI := mongodb.NewAPI(client)
+
+	listDBs, err := mongoAPI.ListInstances(&mongodb.ListInstancesRequest{
+		Region: pn.Region,
+	}, scw.WithContext(ctx), scw.WithAllPages())
+	if err != nil {
+		return nil, err
+	}
+	var customDBs []customMongoDB
+	for _, db := range listDBs.Instances {
+		for _, endpoint := range db.Endpoints {
+			if endpoint.PrivateNetwork != nil && endpoint.PrivateNetwork.PrivateNetworkID == pn.ID {
+				customDBs = append(customDBs, customMongoDB{
+					EndpointID: endpoint.ID,
+					ID:         db.ID,
+					Name:       db.Name,
+					State:      db.Status,
+				})
+			}
+		}
+	}
+
+	return customDBs, nil
+}
+
+func listCustomIPAMIPs(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customIPAMIP, error) {
+	ipamAPI := ipam.NewAPI(client)
+
+	listIPAMIPs, err := ipamAPI.ListIPs(&ipam.ListIPsRequest{
+		Region:           pn.Region,
+		PrivateNetworkID: &pn.ID,
+	}, scw.WithContext(ctx), scw.WithAllPages())
+	if err != nil {
+		return nil, err
+	}
+
+	customIPAMIPs := make([]customIPAMIP, 0, len(listIPAMIPs.IPs))
+	for _, ip := range listIPAMIPs.IPs {
+		customIPAMIPs = append(customIPAMIPs, customIPAMIP{
+			ID:      ip.ID,
+			Address: ip.Address.String(),
+		})
+	}
+
+	return customIPAMIPs, nil
+}
+
+func listCustomInferenceDeployments(
+	ctx context.Context,
+	client *scw.Client,
+	pn *vpc.PrivateNetwork,
+) ([]customInferenceDeployment, error) {
+	inferenceAPI := inference.NewAPI(client)
+
+	listDeployments, err := inferenceAPI.ListDeployments(&inference.ListDeploymentsRequest{
+		Region: pn.Region,
+	}, scw.WithContext(ctx), scw.WithAllPages())
+	if err != nil {
+		return nil, err
+	}
+	var customDeployments []customInferenceDeployment
+	for _, deployment := range listDeployments.Deployments {
+		for _, endpoint := range deployment.Endpoints {
+			if endpoint.PrivateNetwork != nil && endpoint.PrivateNetwork.PrivateNetworkID == pn.ID {
+				customDeployments = append(customDeployments, customInferenceDeployment{
+					EndpointID: endpoint.ID,
+					ID:         deployment.ID,
+					Name:       deployment.Name,
+					State:      deployment.Status,
+				})
+			}
+		}
+	}
+
+	return customDeployments, nil
+}
+
 // intersectZones returns zones common to both provided slices
 func intersectZones(regionZones, apiZones []scw.Zone) []scw.Zone {
 	apiZonesMap := make(map[scw.Zone]bool)
