@@ -3,7 +3,8 @@ package testhelpers
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 // MapValue gets a value from a map[string]any using a given key.
@@ -24,8 +25,8 @@ func MapTValue[T any](t *testing.T, m map[string]T, key string) T {
 	t.Helper()
 
 	item, ok := m[key]
-	assert.True(t, ok, "Requested key %q does not exist in given map", key)
-	assert.NotNil(t, item, "Item is nil")
+	require.True(t, ok, "Requested key %q does not exist in given map", key)
+	require.NotNil(t, item, "Item is nil")
 
 	return item
 }
@@ -35,8 +36,8 @@ func Value[T any](t *testing.T, v any) T {
 	t.Helper()
 
 	typedItem, typeIsCorrect := v.(T)
-	assert.True(t, typeIsCorrect)
-	assert.NotNil(t, typedItem)
+	require.True(t, typeIsCorrect)
+	require.NotNil(t, typedItem, "Item is nil")
 
 	return typedItem
 }
