@@ -1,5 +1,3 @@
 const wasmURL = new URL('cli.wasm', import.meta.url)
 
-export {
-    wasmURL,
-}
+export { wasmURL }
